import QtQuick 1.1
import com.nokia.meego 1.0

Page {
    id:emergencyNumbers

    orientationLock: PageOrientation.LockPortrait

    tools:
        ToolBarLayout {
        ToolIcon { iconId: "toolbar-back"; onClicked: { mainMenu.close(); pageStack.pop(); } }
        ToolIcon {
            Image {
                visible: true
                source: "images/geo-icon.png"
                anchors.verticalCenter: parent.verticalCenter
                anchors.horizontalCenter: parent.horizontalCenter
            }
            onClicked: pageStack.push(Qt.resolvedUrl("NearStations.qml"))
        }
        ToolIcon {
                    iconId: "toolbar-search"
                    onClicked: pageStack.push(Qt.resolvedUrl("SearchNearStations.qml"))
                }
        ToolIcon {
            iconId: "toolbar-view-menu"
            onClicked: (mainMenu.status == DialogStatus.Closed) ? mainMenu.open() : mainMenu.close()
            anchors.right: parent==undefined ? undefined : parent.right
        }
    }

    Rectangle {
            id:header
            width:parent.width
            height: 72
            z:10
            color:"#247800"

            Item {
                anchors.verticalCenter: parent.verticalCenter
                height: headerName.height + headerSubject.height

                Label {
                    id:headerName
                    color:"#fff"
                    text:"Números de Emergencia"
                    anchors.left: parent.left
                    anchors.leftMargin: 16
                    anchors.top: parent.top
                    anchors.topMargin: 0
                    font.pixelSize: 32
                    font.weight: Font.Normal
                    font.family: "Nokia Pure Text"
                    lineHeightMode: Text.FixedHeight
                    lineHeight: font.pixelSize * 1.1
                }
                Label {
                    id:headerSubject
                    color:"#fff"
                    text:"Seleccione un número para llamar"
                    anchors.left: parent.left
                    anchors.leftMargin: 16
                    anchors.top: headerName.bottom
                    anchors.topMargin: 0
                    font.pixelSize: 18
                    font.weight: Font.Normal
                    font.family: "Nokia Pure Text"
                    lineHeightMode: Text.FixedHeight
                    lineHeight: font.pixelSize * 1.1
                }

            }
        }

    ListModel {
        id:emergencyNumbersModel
        ListElement {
            icon: "police.png"
            name: "Carabineros"
            number: "133"
            description:"Atención las 24 horas, envio de patrullas o personal desde la comisaría mas cercana."
        }
        ListElement {
            icon: "same.png"
            name: "Ambulancia"
            number: "131"
            description:"Emergencias médicas, atención las 24 hs, los 365 días del año."
        }
        ListElement {
            icon: "fire.png"
            name: "Bomberos"
            number: "132"
            description:"Emergencias por incendios o rescates, atención las 24 hs, los 365 días del año."
        }
        ListElement {
            icon: "info.png"
            name: "Metro de Santiago"
            number: "9372000"
            description:"Consultas relativas al servicio, atención de accidentes, reclamos y sugerencias."
        }
        ListElement {
            icon: "info.png"
            name: "Transantiago"
            number: "6007300073"
            description:"Consultas o reclamos sobre el servicio, atención las 24 hs, los 365 días del año."
        }
    }

    Component {
            id:emergencyNumbersDelegate

            Item {
                height: 112
                width: parent.width

                BorderImage {
                    id: background
                    anchors.fill: parent
                    // Fill page borders
                    anchors.leftMargin: -emergencyNumbers.anchors.leftMargin
                    anchors.rightMargin: -emergencyNumbers.anchors.rightMargin
                    visible: mouseArea.pressed
                    source: "image://theme/meegotouch-list-fullwidth-background-pressed-center"
                }

                Item {
                    id:listItem
                    anchors.fill: parent
                    Item {
                        id: itemIcon
                        width:96
                        height: 112
                        Image {
                            smooth: true
                            width: 64
                            height: 64
                            source: "images/" + icon
                            anchors.verticalCenter: parent.verticalCenter
                            anchors.horizontalCenter: parent.horizontalCenter
                        }
                    }

                    Item {
                        id: itemLabels
                        width: listItem.width - 124
                        height: itemName.height + itemDescription.height
                        anchors.verticalCenter: parent.verticalCenter
                        anchors.left: itemIcon.right
                        anchors.leftMargin: 8

                        Label {
                            id:itemName
                            text: name + " - " + number
                            font.weight: Font.Bold
                            font.pixelSize: 26
                            width: parent.width
                            lineHeightMode: Text.FixedHeight
                            lineHeight: font.pixelSize * 1.1
                        }
                        Label {
                            id:itemDescription
                            text: description
                            anchors.top: itemName.bottom
                            anchors.topMargin: 0
                            font.weight: Font.Normal
                            font.pixelSize: 22
                            width: parent.width - 8
                            lineHeightMode: Text.FixedHeight
                            lineHeight: font.pixelSize * 1.1
                        }
                    }
                }

                Image {
                    source: "image://theme/icon-m-common-drilldown-arrow" + (theme.inverted ? "-inverse" : "")
                    anchors.right: parent.right
                    anchors.rightMargin: 0
                    anchors.verticalCenter: parent.verticalCenter
                }


                MouseArea {
                    id: mouseArea
                    anchors.fill: background
                    onClicked: {
                        Qt.openUrlExternally("tel:"+number)
                    }
                }
            }
        }

    ListView {
        id:listView
        anchors.fill: parent
        anchors.topMargin: 75
        anchors.bottomMargin: 0
        anchors.left: parent.left
        anchors.right: parent.right
        model:emergencyNumbersModel
        delegate:emergencyNumbersDelegate
    }

    ScrollDecorator {
        flickableItem: listView
    }
}
