import QtQuick 1.1
import com.nokia.meego 1.0

Page {
    id: mainPage

    orientationLock: PageOrientation.LockPortrait

    tools:
        ToolBarLayout {
        //ToolIcon { iconId: "toolbar-back"; onClicked: { mainMenu.close(); pageStack.pop(); } }
        ToolIcon { iconId: "toolbar-back"; opacity: 0;}
        ToolIcon {
            Image {
                visible: true
                source: "images/geo-icon.png"
                anchors.verticalCenter: parent.verticalCenter
                anchors.horizontalCenter: parent.horizontalCenter
            }
            onClicked: pageStack.push(Qt.resolvedUrl("NearStations.qml"))
        }
        ToolIcon {
                    iconId: "toolbar-search"
                    onClicked: pageStack.push(Qt.resolvedUrl("SearchNearStations.qml"))
                }
        ToolIcon {
            iconId: "toolbar-view-menu"
            onClicked: (mainMenu.status == DialogStatus.Closed) ? mainMenu.open() : mainMenu.close()
            anchors.right: parent==undefined ? undefined : parent.right
        }
    }

    ListModel {
        id:linesModel
        Component.onCompleted: {
            window.getManager().generateLinesModel(linesModel);
        }
    }

    Component {
        id:linesDelegate

        Item {
            height: listItem.height
            width: parent.width

            BorderImage {
                id: background
                anchors.fill: parent
                // Fill page borders
                anchors.leftMargin: -mainPage.anchors.leftMargin
                anchors.rightMargin: -mainPage.anchors.rightMargin
                visible: mouseArea.pressed
                source: "image://theme/meegotouch-list-fullwidth-background-pressed-center"
            }

            Item {
                id:listItem
                width:parent.width
                height: itemName.height + itemSubject.height + itemOrientation.height + 16

                Item {
                    id: itemIcon
                    width:96
                    height: parent.height
                    Image {
                        smooth: true
                        width: 64
                        height: 64
                        source: "images/" + letterLine
                        anchors.verticalCenter: parent.verticalCenter
                        anchors.horizontalCenter: parent.horizontalCenter
                    }
                }

                Item {
                    id: itemLabels
                    width: listItem.width - 124
                    height: itemName.height + itemSubject.height + itemOrientation.height
                    anchors.verticalCenter: parent.verticalCenter
                    anchors.left: itemIcon.right
                    anchors.leftMargin: 8

                    Label {
                        id:itemName
                        text: name
                        font.weight: Font.Bold
                        font.pixelSize: 26
                        lineHeightMode: Text.FixedHeight
                        lineHeight: font.pixelSize * 1.1
                    }
                    Label {
                        id:itemSubject
                        text: subject
                        anchors.top: itemName.bottom
                        anchors.topMargin: 0
                        font.weight: Font.Normal
                        font.pixelSize: 22
                        lineHeightMode: Text.FixedHeight
                        lineHeight: font.pixelSize * 1.1
                    }
                    Label {
                        id:itemOrientation
                        font.weight: Font.Normal
                        text: orientation
                        anchors.top: itemSubject.bottom
                        anchors.topMargin: 0
                        font.pixelSize: 18
                        lineHeightMode: Text.FixedHeight
                        lineHeight: font.pixelSize * 1.1
                    }
                }
            }


            Image {
                source: "image://theme/icon-m-common-drilldown-arrow" + (theme.inverted ? "-inverse" : "")
                anchors.right: parent.right
                anchors.rightMargin: 0
                anchors.verticalCenter: parent.verticalCenter
            }

            MouseArea {
                id: mouseArea
                anchors.fill: background
                onClicked: {
                    line_id = id
                    pageStack.push(Qt.resolvedUrl("StationsPage.qml"))
                }
            }
        }
    }

    Rectangle {
        id:header
        width:parent.width
        height: 72
        z:10
        color:"#247800"
        Item {
            anchors.verticalCenter: parent.verticalCenter
            height: headerName.height + headerSubject.height
            Text {
                id:headerName
                color:"#fff"
                text:"MetroGo Santiago"
                anchors.left: parent.left
                anchors.leftMargin: 16
                anchors.top: parent.top
                anchors.topMargin: 0
                font.pixelSize: 32
                font.weight: Font.Normal
                font.family: "Nokia Pure Text"
                lineHeightMode: Text.FixedHeight
                lineHeight: font.pixelSize * 1.1
            }
            Text {
                id:headerSubject
                color:"#fff"
                text:"Seleccione una estación para comenzar"
                anchors.left: parent.left
                anchors.leftMargin: 16
                anchors.top: headerName.bottom
                anchors.topMargin: 0
                font.pixelSize: 18
                font.weight: Font.Normal
                font.family: "Nokia Pure Text"
                lineHeightMode: Text.FixedHeight
                lineHeight: font.pixelSize * 1.1
            }
        }
    }

    ListView {
        id:listView
        anchors.top: header.bottom
        anchors.topMargin: 8
        anchors.right: parent.right
        anchors.left: parent.left
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 8
        model:linesModel
        delegate:linesDelegate
    }

    ScrollDecorator {
        flickableItem: listView
    }
}
